tiled.structures.sparse.COOStructure
====================================

.. currentmodule:: tiled.structures.sparse

.. autoclass:: COOStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~COOStructure.__init__
      ~COOStructure.from_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~COOStructure.dims
      ~COOStructure.layout
      ~COOStructure.resizable
      ~COOStructure.chunks
      ~COOStructure.shape
   
   